<?php
// $Id: botcha.pages.inc,v 1.5 2010/12/08 05:17:43 iva2k Exp $

/**
 * @file
 * Implementation of botcha administration forms.
 */

/**
 * Module settings form.
 */
function _botcha_admin_settings(&$form_state) {
  $form = array();
  
  // Handle the secret key generation upon submit.
  // This is done here for we don't have a submit form yet.
  $secret = variable_get('botcha_secret', '');
  if (isset($form_state['post']['op']) 
    && (!isset($form_state['post']['botcha_secret']) || $form_state['post']['botcha_secret'] == '')) {
    // Generate unique secret for this site  
	$secret = md5(uniqid(mt_rand(), TRUE));
    $form_state['post']['botcha_secret'] = $secret;
	$_POST['botcha_secret'] = $secret;
    drupal_set_message(t('New BOTCHA secret key have been generated.'));
  }
  $form['botcha_secret'] = array(
    '#type' => 'textfield',
    '#title' => t('Secret key'),
    '#default_value' => $secret,
    '#description' => 
      t('It is recommended to enter some random text into the secret key. This setting makes your site\'s BOTCHA challenges unique and harder to break.')
      . '<br>' . t('If you leave this field empty and save configuration, a new random key will be generated for you.')
    ,
  );
 
  // Configuration of which forms to protect, with what recipe.
  $form['botcha_form_protection'] = array(
    '#type' => 'fieldset',
    '#title' => t('Form protection'),
    '#description' => t('Select which forms to protect with BOTCHA')
//      . ' ' . t('Select the recipe you want for each of the listed forms (identified by their so called <em>form_id</em>\'s). You can easily add arbitrary forms with textfield at the bottom of the table or with the help of the \'%BOTCHA_admin_links\' option below.',
//        array('%BOTCHA_admin_links' => t('Add BOTCHA administration links to forms')))
    ,
  );

  // Put on same forms as CAPTCHA.
  $form['botcha_form_protection']['botcha_on_captcha_forms'] = array(
    '#type' => 'checkbox',
    '#title' => t('Add BOTCHA to forms selected for CAPTCHA'),
    '#default_value' => variable_get('botcha_on_captcha_forms', TRUE),
    '#description' => t('This option makes it easy to manage BOTCHA settings on forms. When enabled, all forms that are configured to have CAPTCHA on them (<a href="@captcha">see configuration</a>) will be also be selected for BOTCHA protection.!more', 
       array('@captcha' => url('admin/user/captcha'),
         '!more' => module_exists('captcha') ? '' : '<br>' . t('<b>Note:</b> <a href="@captcha_home">CAPTCHA module</a> is not installed. This setting will have no effect.',
           array('@captcha_home' => 'http://drupal.org/project/captcha')
         ),
       )),
  );

/* UNUSED:
  // Field for the BOTCHA administration mode.
  $form['botcha_form_protection']['botcha_administration_mode'] = array(
    '#type' => 'checkbox',
    '#title' => t('Add BOTCHA administration links to forms'),
    '#default_value' => variable_get('botcha_administration_mode', FALSE),
    '#description' => t('This option makes it easy to manage BOTCHA settings on forms. When enabled, users with the "%adminbotcha" permission will see a fieldset with BOTCHA administration links on all forms, except on administrative pages.', array('%adminbotcha' => t('administer BOTCHA settings'))),
  );
  // Field for the BOTCHAs on admin pages.
  $form['botcha_form_protection']['botcha_allow_on_admin_pages'] = array(
    '#type' => 'checkbox',
    '#title' => t('Allow BOTCHAs and BOTCHA administration links on administrative pages'),
    '#default_value' => variable_get('botcha_allow_on_admin_pages', FALSE),
    '#description' => t('This option makes it possible to add BOTCHAs to forms on administrative pages. BOTCHAs are disabled by default on administrative pages (which shouldn\'t be accessible to untrusted users normally) to avoid the related overhead. In some situations, e.g. in the case of demo sites, it can be usefull to allow BOTCHAs on administrative pages.'),
  );
/**/

  // BOTCHA Statistics & Logging
  $form['botcha_statistics'] = array(
    '#type' => 'fieldset',
    '#title' => t('Statistics & logging'),
    '#description' => t('BOTCHA collects statistics of form submissions and it can report different events into the system log.'),
  );
  $form['botcha_statistics']['botcha_loglevel'] = array(
    '#type' => 'select',
    '#title' => t('Log level'),
    '#default_value' => variable_get('botcha_loglevel', 1),
    '#options' => array(
      0 => t('0: no log'),
      1 => t('1: blocked/bad submissions only'),
      2 => t('2: ... and good submissions'),
      3 => t('3: ... and protected forms'),
      4 => t('4: ... and extra details'),
      5 => t('5: ... and misc development items'),
    ),
    '#description' => t('Select what information to report into the !log.', array('!log' => l(t('log'), 'admin/reports/dblog'))),
  );
  // Button for resetting the BOTCHA statistics.
  $form['botcha_statistics']['botcha_statistics_group'] = array(
    '#type' => 'item',
    '#title' => t('BOTCHA statistics'),
    '#description' => t('Reset all accumulated statistics of form submissions.'),
  );
  $form['botcha_statistics']['botcha_statistics_group']['botcha_statistics_reset'] = array(
    '#type' => 'button',
    '#value' => t('Reset BOTCHA statistics'),
    '#submit' => array('botcha_statistics_reset'),
  );
  // Handle the button for resetting the BOTCHA statistics.
  // This is done here instead of in a submit handler because the button is
  // not a submitting button.
  if (isset($form_state['post']['op']) && $form_state['post']['op']
    == $form['botcha_statistics']['botcha_statistics_group']['botcha_statistics_reset']['#value']) {
    variable_set('botcha_form_passed_counter',0);
    variable_set('botcha_form_blocked_counter',0);
    drupal_set_message(t('BOTCHA statistics have been reset.'));
  }

  return $form;
}
function botcha_admin_settings(&$form_state) {
  return system_settings_form(_botcha_admin_settings($form_state));
}

